==> zio-aws-wafregional_3-5.17.121.3-sources.jar: zio/aws/wafregional/model/RegexPatternSet.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.{
  RegexPatternString,
  ResourceName,
  ResourceId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class RegexPatternSet(
    regexPatternSetId: ResourceId,
    name: Option[ResourceName] = None,
    regexPatternStrings: Iterable[RegexPatternString]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.RegexPatternSet = {
    import RegexPatternSet.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.RegexPatternSet
      .builder()
      .regexPatternSetId(ResourceId.unwrap(regexPatternSetId): java.lang.String)
      .optionallyWith(
        name.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.name)
      .regexPatternStrings(regexPatternStrings.map { item =>
        RegexPatternString.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.RegexPatternSet.ReadOnly =
    zio.aws.wafregional.model.RegexPatternSet.wrap(buildAwsValue())
}
object RegexPatternSet {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.RegexPatternSet
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.RegexPatternSet =
      zio.aws.wafregional.model.RegexPatternSet(
        regexPatternSetId,
        name.map(value => value),
        regexPatternStrings
      )
    def regexPatternSetId: ResourceId
    def name: Option[ResourceName]
    def regexPatternStrings: List[RegexPatternString]
    def getRegexPatternSetId: ZIO[Any, Nothing, ResourceId] =
      ZIO.succeed(regexPatternSetId)
    def getName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("name", name)
    def getRegexPatternStrings: ZIO[Any, Nothing, List[RegexPatternString]] =
      ZIO.succeed(regexPatternStrings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.RegexPatternSet
  ) extends zio.aws.wafregional.model.RegexPatternSet.ReadOnly {
    override val regexPatternSetId: ResourceId =
      zio.aws.wafregional.model.primitives.ResourceId(impl.regexPatternSetId())
    override val name: Option[ResourceName] = scala
      .Option(impl.name())
      .map(value => zio.aws.wafregional.model.primitives.ResourceName(value))
    override val regexPatternStrings: List[RegexPatternString] = impl
      .regexPatternStrings()
      .asScala
      .map { item =>
        zio.aws.wafregional.model.primitives.RegexPatternString(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.RegexPatternSet
  ): zio.aws.wafregional.model.RegexPatternSet.ReadOnly = new Wrapper(impl)
}

==> zio-aws-wafregional_3-5.17.295.22-sources.jar: zio/aws/wafregional/model/RegexPatternSet.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.{
  RegexPatternString,
  ResourceName,
  ResourceId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class RegexPatternSet(
    regexPatternSetId: ResourceId,
    name: Optional[ResourceName] = Optional.Absent,
    regexPatternStrings: Iterable[RegexPatternString]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.RegexPatternSet = {
    import RegexPatternSet.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.RegexPatternSet
      .builder()
      .regexPatternSetId(ResourceId.unwrap(regexPatternSetId): java.lang.String)
      .optionallyWith(
        name.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.name)
      .regexPatternStrings(regexPatternStrings.map { item =>
        RegexPatternString.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.RegexPatternSet.ReadOnly =
    zio.aws.wafregional.model.RegexPatternSet.wrap(buildAwsValue())
}
object RegexPatternSet {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.RegexPatternSet
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.RegexPatternSet =
      zio.aws.wafregional.model.RegexPatternSet(
        regexPatternSetId,
        name.map(value => value),
        regexPatternStrings
      )
    def regexPatternSetId: ResourceId
    def name: Optional[ResourceName]
    def regexPatternStrings: List[RegexPatternString]
    def getRegexPatternSetId: ZIO[Any, Nothing, ResourceId] =
      ZIO.succeed(regexPatternSetId)
    def getName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("name", name)
    def getRegexPatternStrings: ZIO[Any, Nothing, List[RegexPatternString]] =
      ZIO.succeed(regexPatternStrings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.RegexPatternSet
  ) extends zio.aws.wafregional.model.RegexPatternSet.ReadOnly {
    override val regexPatternSetId: ResourceId =
      zio.aws.wafregional.model.primitives.ResourceId(impl.regexPatternSetId())
    override val name: Optional[ResourceName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.wafregional.model.primitives.ResourceName(value))
    override val regexPatternStrings: List[RegexPatternString] = impl
      .regexPatternStrings()
      .asScala
      .map { item =>
        zio.aws.wafregional.model.primitives.RegexPatternString(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.RegexPatternSet
  ): zio.aws.wafregional.model.RegexPatternSet.ReadOnly = new Wrapper(impl)
}
